# PyBpod GUI Plugin Timeline

This plugin plots each trial state change.

## How to install

* Install Pyforms Generic Editor.
* Add this plugin on  the file "pyforms_generic_editor_user_settings.py":


    GENERIC_EDITOR_PLUGINS_LIST = [
        'pybpodgui_plugin',
        'pybpodgui_plugin_timeline',
    ]

